@@ -1,12 +1,13 @@
-#! perl
+#! perl --			-*- coding: utf-8 -*-
+
+use utf8;
 
 # EB.pm -- EekBoek Base module.
-# RCS Info        : $Id: EB.pm,v 1.87 2009/04/03 09:41:55 jv Exp $
 # Author          : Johan Vromans
 # Created On      : Fri Sep 16 18:38:45 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Mon Oct  6 14:50:32 2008
-# Update Count    : 221
+# Last Modified On: Tue Jan 31 12:03:31 2017
+# Update Count    : 322
 # Status          : Unknown, Use with caution!
 
 package main;
@@ -16,8 +17,6 @@ our $cfg;
 
 package EB;
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.87 $ =~ /(\d+)/g;
-
 use strict;
 use base qw(Exporter);
 
@@ -26,66 +25,83 @@ use EekBoek;
 our @EXPORT;
 our @EXPORT_OK;
 
-# Establish location of our data, relative to this module.
+# Establish location of our run-time resources.
 my $lib;
-BEGIN {
-    $lib = $INC{"EB.pm"};
-    $lib =~ s/EB\.pm$//;
-    $ENV{EB_LIB} = $lib;
-    # warn("lib = $lib\n");
+sub libfile {
+    my ($f) = @_;
+
+    unless ( $lib ) {
+	# Cava.
+	if ( $Cava::Packager::PACKAGED ) {
+	    return Cava::Packager::GetResourcePath()."/$f";
+	}
+	else {
+	    $lib = $INC{"EB.pm"};
+	    $lib =~ s/EB\.pm$//;
+	}
+    }
+    $lib."EB/res/$f";
 }
 
-# Make it accessible.
-sub EB_LIB() { $lib }
+sub findlib {
+    my ($file, $section) = @_;
 
-# Some standard modules.
+    # The two-argument form supports locale-dependent paths, but
+    # we hard-wire this to 'nl'.
+    if ( $section ) {
+	my $lang = 'nl';
+	my $found = findlib( "$section/$lang/$file" );
+	return $found if $found;
+	$found = findlib( "$section/$file" );
+	return $found if $found;
+	return undef;
+    }
+
+    # Cava.
+    if ( $Cava::Packager::PACKAGED ) {
+	my $found = Cava::Packager::GetUserFile($file);
+	return $found if -e $found;
+	$found = Cava::Packager::GetResource($file);
+	return $found if -e $found;
+    }
+
+    foreach ( @INC ) {
+	return "$_/EB/user/$file" if -e "$_/EB/user/$file";
+	return "$_/EB/res/$file" if -e "$_/EB/res/$file";
+	return "$_/EB/$file" if -e "$_/EB/$file";
+    }
+    undef;
+}
+
+use lib ( grep { defined } findlib("CPAN") );
+
+# Some standard modules (locale-free).
 use EB::Globals;
 use Carp;
-use EB::Assert;
 use Data::Dumper;
-
-BEGIN {
-    # The core and GUI use a different EB::Locale module.
-    if ( $app ) {
-	require EB::Wx::Locale;
-	# Force UNICODE for Wx.
-	$cfg->newval(qw(locale unicode), 1);
-    }
-    else {
-	require EB::Locale;
-    }
-    EB::Locale::->import;
-}
-
-# Utilities.
+use Carp::Assert;
 use EB::Utils;
 
+# Even though we do not use translations, most of the code is in place.
+sub _T { $_[0] }
+
 # Export our and the imported globals.
-BEGIN {
-    @EXPORT = ( qw(EB_LIB),
-		@EB::Globals::EXPORT,
-		@EB::Utils::EXPORT,
-		@EB::Locale::EXPORT,
-		qw(carp croak),
-		qw(Dumper),
-		qw(findlib),
-		qw(assert affirm),
-	      );
-}
+@EXPORT = ( @EB::Globals::EXPORT,
+	    @EB::Utils::EXPORT,
+	    "_T",			# @EB::Locale::EXPORT,
+	    qw(carp croak),		# Carp
+	    qw(Dumper),			# Data::Dumper
+	    qw(findlib libfile),	# <self>
+	    qw(assert affirm),		# Carp::Assert
+	  );
 
-our @months;
-our @month_names;
-our @days;
-our @day_names;
 our $ident;
 our $imsg;
+my $imsg_saved;
 our $url = "http://www.eekboek.nl";
 
-# Most elegant (and correct) would be to use an INIT block here, but
-# currently PAR is not able to handle INIT blocks.
-INIT {
-    return if $ident;		# already done
-    my $incompatibleOS = 0;
+sub __init__ {
+    $imsg_saved = $imsg || "";
 
     my $year = 2005;
     my $thisyear = (localtime(time))[5] + 1900;
@@ -93,15 +109,15 @@ INIT {
     $ident = __x("{name} {version}",
 		 name    => $EekBoek::PACKAGE,
 		 version => $EekBoek::VERSION);
-    my @locextra;
-    push(@locextra, _T("Nederlands")) if LOCALISER;
-    push(@locextra, "Latin1") unless $cfg->val(qw(locale unicode), 0);
-    $imsg = __x("{ident}{extra}{locale} -- Copyright {year} Squirrel Consultancy",
+    $imsg = __x("{ident}{extra} -- Copyright {year} Squirrel Consultancy",
 		ident   => $ident,
-		extra   => ($app ? " Wx " : ""),
-		locale  => (@locextra ? " (".join(", ", @locextra).")" : ""),
+		extra   => ($app ? " Wx" : ""),
 		year    => $year);
-    warn($imsg, "\n") unless @ARGV && $ARGV[0] =~ /-(P|-?printcfg)$/;
+    if ( $imsg ne $imsg_saved
+	 && !( @ARGV && $ARGV[0] =~ /-(P|-?printconfig)$/ )
+       ) {
+	warn($imsg, "\n");
+    }
 
     eval {
 	require Win32;
@@ -109,34 +125,33 @@ INIT {
 	my ($id, $major) = @a[4,1];
 	die unless defined $id;
 	warn(_T("EekBoek is VRIJE software, ontwikkeld om vrij over uw eigen gegevens te kunnen beschikken.")."\n");
-	if ( $cfg->val(qw(security override_security_for_vista), 0)
-	     or
-	     ( $id <= 1 || ( $id == 2 && $major <= 5) || $id >= 3 ) ) {
-	    warn(_T("Met uw keuze voor het Microsoft Windows besturingssysteem geeft u echter alle vrijheden weer uit handen. Dat is erg triest.")."\n");
-	}
-	else {
-	    $incompatibleOS++;
-	    warn(_T("Dit is niet te verenigen met uw keuze voor dit Microsoft Windows besturingssysteem.")."\n");
-	}
-    } unless $ENV{AUTOMATED_TESTING};
+	warn(_T("Met uw keuze voor het Microsoft Windows besturingssysteem geeft u echter alle vrijheden weer uit handen. Dat is erg triest.")."\n");
+    } unless $imsg_saved eq $imsg || $ENV{AUTOMATED_TESTING};
 
-    @months =
-      split(" ", _T("Jan Feb Mrt Apr Mei Jun Jul Aug Sep Okt Nov Dec"));
-    @month_names =
-      split(" ", _T("Januari Februari Maart April Mei Juni Juli Augustus September Oktober November December"));
-    @days =
-      split(" ", _T("Zon Maa Din Woe Don Vri Zat"));
-    @day_names =
-      split(" ", _T("Zondag Maandag Dinsdag Woensdag Donderdag Vrijdag Zaterdag"));
-    die("?"._T("FATALE FOUT: Ongeschikt besturingssysteem")."\n") if $incompatibleOS;
 }
 
-sub findlib {
-    my ($file) = @_;
-    foreach ( @INC ) {
-	return "$_/EB/$file" if -e "$_/EB/$file";
-    }
-    undef;
+sub app_init {
+    shift;			# 'EB'
+
+    # Load a config file.
+    require EB::Config;
+    undef $::cfg;
+    EB::Config->init_config( @_ );
+
+    # Main initialisation.
+    __init__();
+
+    # Initialise locale-dependent formats.
+    require EB::Format;
+    EB::Format->init_formats();
+
+    return $::cfg;		# until we've got something better
+}
+
+sub EB::Config::Handler::connect_db {
+    # Connect to the data base.
+    require EB::DB;
+    EB::DB::->connect;
 }
 
 1;
@@ -174,7 +189,7 @@ Web site: L<http://www.eekboek.nl>.
 
 =head1 COPYRIGHT AND DISCLAIMER
 
-This program is Copyright 2005-2008 by Squirrel Consultancy. All
+This program is Copyright 2005-2011 by Squirrel Consultancy. All
 rights reserved.
 
 This program is free software; you can redistribute it and/or modify
